@@ -2,9 +2,9 @@
 from __future__ import absolute_import
 
 import os
-import subprocess
+import six
 import sys
-import yaml
+from pipes import quote
 
 from django.conf import settings as django_settings
 from django.template import loader, Context
@@ -13,6 +13,12 @@ import click
 
 from aldryn_addons.utils import openfile, boolean_ish
 
+if six.PY2:
+    # backport of python3 subprocess with timeout support
+    import subprocess32 as subprocess
+else:
+    import subprocess
+
 
 # add the current directory to pythonpath. So the project files can be read.
 BASE_DIR = os.getcwd()
@@ -88,14 +94,32 @@ main.add_command(worker)
 main.add_command(migrate)
 
 
+def get_env():
+    # setup default uwsgi environment variables
+    env = {
+        'UWSGI_ENABLE_THREADS': '1',
+    }
+    if boolean_ish(os.environ.get('ENABLE_UWSGI_CHEAPER', 'on')):
+        env.update({
+            'UWSGI_CHEAPER': '1',
+            'UWSGI_CHEAPER_ALGO': 'busyness',
+            'UWSGI_CHEAPER_INITIAL': '1',
+            'UWSGI_CHEAPER_BUSINESS_VERBOSE': '1',
+            'UWSGI_CHEAPER_BUSINESS_BACKLOG_ALERT': '10',
+            'UWSGI_CHEAPER_OVERLOAD': '30',
+        })
+    env.update(os.environ)
+    return env
+
+
 def execute(args, script=None):
     # TODO: is cleanup needed before calling exec? (open files, ...)
     command = script or args[0]
-    os.execvp(command, args)
+    os.execvpe(command, args, get_env())
 
 
 def start_uwsgi_command(settings, port=None):
-    return [
+    cmd = [
         'uwsgi',
         '--module=wsgi',
         '--http=0.0.0.0:{}'.format(port or settings.get('PORT')),
@@ -103,10 +127,60 @@ def start_uwsgi_command(settings, port=None):
         '--workers={}'.format(settings['DJANGO_WEB_WORKERS']),
         '--max-requests={}'.format(settings['DJANGO_WEB_MAX_REQUESTS']),
         '--harakiri={}'.format(settings['DJANGO_WEB_TIMEOUT']),
-        # '--honour-stdin',
         '--lazy-apps',
     ]
 
+    serve_static = False
+
+    if not settings['ENABLE_SYNCING']:
+        if not settings['STATIC_URL_IS_ON_OTHER_DOMAIN']:
+            serve_static = True
+            cmd.extend([
+                '--static-map={}={}'.format(
+                    settings['STATIC_URL'],
+                    settings['STATIC_ROOT'],
+                ),
+                # Set far-future expiration headers for django-compressor
+                # generated files
+                '--static-expires={} 31536000'.format(
+                    os.path.join(
+                        settings['STATIC_ROOT'],
+                        settings.get('COMPRESS_OUTPUT_DIR', 'CACHE'),
+                        '.*',
+                    )
+                ),
+                # Set far-future expiration headers for static files with
+                # hashed filenames
+                '--static-expires={} 31536000'.format(
+                    os.path.join(
+                        settings['STATIC_ROOT'],
+                        r'.*\.[0-9a-f]{10,16}\.[a-z]+',
+                    )
+                ),
+            ])
+
+        if not settings['MEDIA_URL_IS_ON_OTHER_DOMAIN']:
+            serve_static = True
+            cmd.append('--static-map={}={}'.format(
+                settings['MEDIA_URL'],
+                settings['MEDIA_ROOT'],
+            ))
+
+        if serve_static:
+            cmd.extend([
+                # Start 2 offloading threads for each worker
+                '--offload-threads=2',
+                # Cache resolved paths for up to 1 day (limited to 5k entries
+                # of max 1kB size each)
+                '--static-cache-paths=86400',
+                '--static-cache-paths-name=staticpaths',
+                '--cache2=name=staticpaths,items=5000,blocksize=1k,purge_lru,ignore_full',
+                # Serve .gz files if that version is available
+                '--static-gzip-all',
+            ])
+
+    return cmd
+
 
 def start_procfile_command(procfile_path):
     return [
@@ -126,14 +200,16 @@ def start_with_nginx(settings):
         raise click.UsageError(
             'NGINX_CONF_PATH and NGINX_PROCFILE_PATH must be configured'
         )
-    procfile = yaml.safe_dump(
-        {
-            'nginx': 'nginx',
-            'django': ' '.join(
-                start_uwsgi_command(settings, port=settings['BACKEND_PORT'])
-            )
-        },
-        default_flow_style=False,
+
+    commands = {
+        'nginx': 'nginx',
+        'django': ' '.join(quote(c) for c in start_uwsgi_command(
+            settings, port=settings['BACKEND_PORT']))
+    }
+
+    procfile = '\n'.join(
+        '{}: {}'.format(name, command)
+        for name, command in commands.items()
     )
 
     if (
