@@ -1,19 +1,7 @@
 import os
 import re
-import shutil
-import gzip
 
 from django.conf import settings
-from django.contrib.staticfiles.storage import (
-    StaticFilesStorage,
-    ManifestStaticFilesStorage,
-)
-from django.core.files.storage import FileSystemStorage
-
-from boto.s3.connection import (
-    SubdomainCallingFormat,
-    OrdinaryCallingFormat,
-)
 
 from six.moves.urllib import parse
 from storages.backends import s3boto
@@ -31,24 +19,16 @@ parse.uses_netloc.append('djfs')
 
 class S3MediaStorage(s3boto.S3BotoStorage):
     def __init__(self):
-        bucket_name = settings.AWS_MEDIA_STORAGE_BUCKET_NAME
-
-        if '.' in bucket_name:
-            calling_format = OrdinaryCallingFormat()
-        else:
-            calling_format = SubdomainCallingFormat()
-
         # We cannot use a function call or a partial here. Instead, we have to
         # create a subclass because django tries to recreate a new object by
         # calling the __init__ of the returned object (with no arguments).
         super(S3MediaStorage, self).__init__(
             access_key=settings.AWS_MEDIA_ACCESS_KEY_ID,
             secret_key=settings.AWS_MEDIA_SECRET_ACCESS_KEY,
-            bucket_name=bucket_name,
+            bucket_name=settings.AWS_MEDIA_STORAGE_BUCKET_NAME,
             location=settings.AWS_MEDIA_BUCKET_PREFIX,
             host=settings.AWS_MEDIA_STORAGE_HOST,
             custom_domain=settings.AWS_MEDIA_DOMAIN,
-            calling_format=calling_format,
             # Setting an ACL requires us to grant the user the PutObjectAcl
             # permission as well, even if it matches the default bucket ACL.
             # XXX: Ideally we would thus set it to `None`, but due to how
@@ -61,8 +41,8 @@ class S3MediaStorage(s3boto.S3BotoStorage):
         # to match against a path, and a dictionary of HTTP headers to be
         # returned with the resource identified by the path when it is
         # requested.
-        # The headers are applied in the order they where declared, and
-        # processing stops at the first match.
+        # The headers are applied in the order they where declared, with
+        # later values overriding the former ones.
         # E.g.:
         #
         #    MEDIA_HEADERS = [
@@ -80,7 +60,6 @@ class S3MediaStorage(s3boto.S3BotoStorage):
         for pattern, headers_override in self.media_headers:
             if pattern.match(path) is not None:
                 headers.update(headers_override)
-                break
         return headers
 
     def _save_content(self, key, content, headers):
@@ -91,7 +70,7 @@ class S3MediaStorage(s3boto.S3BotoStorage):
         return self._decode_name(key.key)[len(self.location):].lstrip('/')
 
     def update_headers(self):
-        updated, total = 0, 0
+        files, updated = 0, 0
 
         dirlist = self.bucket.list(self._encode_name(self.location))
         for key in dirlist:
@@ -109,18 +88,14 @@ class S3MediaStorage(s3boto.S3BotoStorage):
             new_headers = self._headers_for_path(path, new_headers)
             new_headers = {k.lower(): v for k, v in new_headers.items()}
 
-            total += 1
+            files += 1
 
             if new_headers != old_headers:
-                key.copy(
-                    self.bucket.name, key,
-                    metadata=new_headers,
-                    preserve_acl=True,
-                    validate_dst_bucket=False,
-                )
+                key.copy(self.bucket.name, key,
+                         metadata=new_headers, preserve_acl=True)
                 updated += 1
 
-        return updated, total
+        return files, updated
 
 
 def parse_storage_url(url):
@@ -135,15 +110,12 @@ def parse_storage_url(url):
         os.environ['S3_USE_SIGV4'] = 'True'
 
         media_domain = parse.parse_qs(url.query).get('domain', [None])[0]
-        endpoint = url.hostname.rsplit('.', 3)
-        bucket_name = endpoint[0]
-        storage_host = '.'.join(endpoint[1:])
 
         config.update({
             'AWS_MEDIA_ACCESS_KEY_ID': parse.unquote(url.username or ''),
             'AWS_MEDIA_SECRET_ACCESS_KEY': parse.unquote(url.password or ''),
-            'AWS_MEDIA_STORAGE_BUCKET_NAME': bucket_name,
-            'AWS_MEDIA_STORAGE_HOST': storage_host,
+            'AWS_MEDIA_STORAGE_BUCKET_NAME': url.hostname.split('.', 1)[0],
+            'AWS_MEDIA_STORAGE_HOST': url.hostname.split('.', 1)[1],
             'AWS_MEDIA_BUCKET_PREFIX': url.path.lstrip('/'),
             'AWS_MEDIA_DOMAIN': media_domain,
         })
@@ -186,67 +158,3 @@ def parse_storage_url(url):
         # string if it does not end with a '/'
         config['MEDIA_URL'] = '{}/'.format(config['MEDIA_URL'])
     return config
-
-
-class GZippedStaticFilesMixin(object):
-    """
-    Static files storage mixin to create a gzipped version of each static
-    file, so that web servers (e.g. uWSGI) can take advantage of it and
-    serve the optimized version.
-    """
-    gzip_ext = frozenset([
-        '.html',
-        '.css',
-        '.js',
-        '.json',
-        '.svg',
-        '.txt',
-    ])
-
-    def gzip_path(self, path):
-        gz_path = path + '.gz'
-        with self.open(path) as f_in:
-            with self.open(gz_path, 'wb') as f_out:
-                with gzip.GzipFile(fileobj=f_out) as gz_out:
-                    shutil.copyfileobj(f_in, gz_out)
-        return gz_path
-
-    def iterfiles(self, path=''):
-        dirs, files = self.listdir(path)
-        for dir in dirs:
-            for file in self.iterfiles(os.path.join(path, dir)):
-                yield file
-        for file in files:
-            yield os.path.join(path, file)
-
-    def post_process(self, paths, dry_run=False, **options):
-        superclass = super(GZippedStaticFilesMixin, self)
-        if hasattr(superclass, 'post_process'):
-            post_processed = (
-                superclass.post_process(paths, dry_run=dry_run, **options)
-            )
-        else:
-            post_processed = []
-
-        for processed in post_processed:
-            yield processed
-
-        if dry_run:
-            return
-
-        if not isinstance(self, FileSystemStorage):
-            return
-
-        for path in self.iterfiles():
-            if os.path.splitext(path)[1] in self.gzip_ext:
-                self.gzip_path(path)
-
-
-class GZippedStaticFilesStorage(GZippedStaticFilesMixin,
-                                StaticFilesStorage):
-    pass
-
-
-class ManifestGZippedStaticFilesStorage(GZippedStaticFilesMixin,
-                                        ManifestStaticFilesStorage):
-    pass
